@@ -479,6 +479,9 @@ Rcpp::List interval_optim(
   unsigned max;
   unsigned min;
   unsigned size = data.size();
+  if(size < 3){
+    Rcpp::stop("Minimum size required for interval optimization is 3.\n");
+  }
   //unsigned int n = 2; // number of parameters
 
   // only x[0] = b = par[0] and x[1]=m = par[2] are optimized
@@ -507,22 +510,33 @@ Rcpp::List interval_optim(
   // m is always bounded by xmin and xmax
   type[m_position] = 3;
 
-  // this finds the index of the maximum value below
-  // the estimated location parameter
-  // the loop advances until it finds the first data
-  // point that is bigger than m
+  // the code below finds the index position of a value that
+  // is close to the provided m parameter
+  // It makes sense because since the vector is ordered, if m is a good guess
+  // it will be close to the median/half of the vector
+  // par[m_position] = location parameter
+
+  // the for loop finds the index that is immediatelly above m
   for(i = 0; data[i]<=par[m_position] && i<size; i++);
 
-  // this corrects the value of the index
-  // to get the value imediatelly below m
-  if(i == 0) // this corrects for 2 data points
-    index = 0;
-  // not sure why this exists, can't think of a use case
+  // if there is no value below m, we get the second
+  // entry (in an ordered vector)
+  // this is necessary because the interval optimization will start at the first
+  // entry to the left of the index. If the index were at 0, then trying to
+  // access data[-1] would create a segfault
+  if (i == 0)
+    index = 1;
+  // if m is bigger than all elements, then the optm. gets the second-to-last
+  // index for the same reason as before. The right optimization starts on the
+  // first element on the right of the index. If it were at size-1, then
+  // data[size] would throw a segfault error. That's why the minimum vector
+  // size is three
   else if (i == size)
     index= size-2;
-  // default route, it becomes one data point below
-  // the m value
-  else index = i-1;
+  // default route, it becomes smaller or equal to m
+  // when there is just three elements, it always starts on the middle
+  // so the algorithm can always perform the initial step of the optimization
+  else index = i;
 
   // set m value
   set_m(data, xtmp, m_position, xmin, xmax, index);
@@ -534,33 +548,33 @@ Rcpp::List interval_optim(
   // initial optimization
   // minimization
   multimin(
-           data             // sample
-           ,n_param         // number of parameters
-           ,xtmp            // starting guess / returns parameters value
-           ,&dtmp1          // pointer to update the minimum likelihood
-           ,type            // type of transformation of the data
-           ,xmin            // minimum values for the parameters
-           ,xmax            // maximum values for the parameters
-           ,f               // objective function to minimize
-           ,df              // df/dx of the objective function
-           ,fdf             // objf + objdf
-           ,NULL            // fparams
-           ,interv_oparams  // parameters for the optmization
-           ,verb            // set verbosity level
-           );
+    data             // sample
+    ,n_param         // number of parameters
+    ,xtmp            // starting guess / returns parameters value
+    ,&dtmp1          // pointer to update the minimum likelihood
+    ,type            // type of transformation of the data
+    ,xmin            // minimum values for the parameters
+    ,xmax            // maximum values for the parameters
+    ,f               // objective function to minimize
+    ,df              // df/dx of the objective function
+    ,fdf             // objf + objdf
+    ,NULL            // fparams
+    ,interv_oparams  // parameters for the optmization
+    ,verb            // set verbosity level
+  );
 
   // updates minimum values and parameters
   // we use arrows #>>> to represent a new minimum
   check_new_minimum(
-                    data
-                    ,&fmin
-                    ,dtmp1
-                    ,par
-                    ,xtmp
-                    ,index  // this is not used here, we just maintain the same index
-                    ,&index
-                    ,verb
-                    );
+    data
+    ,&fmin
+    ,dtmp1
+    ,par
+    ,xtmp
+    ,index  // this is not used here, we just maintain the same index
+    ,&index
+    ,verb
+  );
 
 
   // set values to the last best value
@@ -601,32 +615,32 @@ Rcpp::List interval_optim(
       // initial optimization
       // minimization
       multimin(
-               data             // sample
-               ,n_param         // number of parameters
-               ,xtmp            // starting guess / returns parameters value
-               ,&dtmp1          // pointer to update the minimum likelihood
-               ,type            // type of transformation of the data
-               ,xmin            // minimum values for the parameters
-               ,xmax            // maximum values for the parameters
-               ,f               // objective function to minimize
-               ,df              // df/dx of the objective function
-               ,fdf             // objf + objdf
-               ,NULL            // fparams
-               ,interv_oparams  // parameters for the optmization
-               ,verb            // set verbosity level
-               );
+        data             // sample
+        ,n_param         // number of parameters
+        ,xtmp            // starting guess / returns parameters value
+        ,&dtmp1          // pointer to update the minimum likelihood
+        ,type            // type of transformation of the data
+        ,xmin            // minimum values for the parameters
+        ,xmax            // maximum values for the parameters
+        ,f               // objective function to minimize
+        ,df              // df/dx of the objective function
+        ,fdf             // objf + objdf
+        ,NULL            // fparams
+        ,interv_oparams  // parameters for the optmization
+        ,verb            // set verbosity level
+      );
 
       // updates minimum values and parameters
       check_new_minimum(
-                        data
-                        ,&fmin
-                        ,dtmp1
-                        ,par
-                        ,xtmp
-                        ,i
-                        ,&index
-                        ,verb
-                        );
+        data
+        ,&fmin
+        ,dtmp1
+        ,par
+        ,xtmp
+        ,i
+        ,&index
+        ,verb
+      );
 
     }
     // counts the number of intervals explored
@@ -648,7 +662,9 @@ Rcpp::List interval_optim(
     // computation
     Rcpp::checkUserInterrupt();
 
-    for(i = min-1; i >= min-interv_step && i >= 0; i--){
+    // i>0 so we never search below the beginning of the vector causing
+    // a segfault
+    for(i = min-1; i >= min-interv_step && i > 0; i--){
 
       // set initial condition
       Rcppdeepcopy(par, xtmp); // set values to the last best value
