@@ -423,7 +423,7 @@ void subboa_objfdf(
 //'
 //' \code{subboafit} returns the parameters, standard errors. negative
 //' log-likelihood and covariance matrix of the asymmetric power exponential for
-//' a sample. The process can execute two steps, dependending on the level of
+//' a sample. The process can execute two steps, depending on the level of
 //' accuracy required. See details below.
 //'
 //' The AEP is a exponential power distribution controlled
@@ -439,7 +439,7 @@ void subboa_objfdf(
 //' where \eqn{l} and \eqn{r} represent left and right tails, \eqn{a*} are
 //' scale parameters, \eqn{b*} control the tails (lower values represent
 //' fatter tails), and \eqn{m} is a location parameter. Due to its lack of
-//' simmetry, and differently from the Subbotin, there is no simple equations
+//' symmetry, and differently from the Subbotin, there is no simple equations
 //' available to use the method of moments, so we start directly by minimizing
 //' the negative log-likelihood. This global optimization is executed without
 //' restricting any parameters. If required (default), after the global
@@ -454,7 +454,7 @@ void subboa_objfdf(
 //'
 //' @param data (NumericVector) - the sample used to fit the distribution.
 //' @param verb (int) - the level of verbosity. Select one of:
-//' * 0  just the final result
+//' * 0  just the final result (default)
 //' * 1  headings and summary table
 //' * 2  intermediate steps results
 //' * 3  intermediate steps internals
@@ -464,12 +464,13 @@ void subboa_objfdf(
 //' * 0 no optimization perform - just return the log-likelihood from initial guess.
 //' * 1 global optimization not considering lack of smoothness in m
 //' * 2 interval optimization taking non-smoothness in m into consideration
+//'   (default, only occurs if provided_m_ is null)
 //' @param interv_step  int - the number of intervals to be explored after
 //' the last minimum was found in the interval optimization. Default is 10.
-//' @param provided_m_ NumericVector - if NULL, the m parameter is estimated
-//' by the routine. If numeric, the estimation fixes m to the given value.
+//' @param provided_m_ NumericVector - if NULL (default), the m parameter is
+//' estimated by the routine. If numeric, the estimation fixes m to the given value.
 //' @param par NumericVector - vector containing the initial guess for
-//' parameters bl, br, al, ar and m, respectively. Default values of are
+//' parameters bl, br, al, ar and m, respectively. Default values are
 //' c(2, 2, 1, 1, 0).
 //' @param g_opt_par NumericVector - vector containing the global optimization
 //' parameters.
@@ -506,7 +507,7 @@ void subboa_objfdf(
 Rcpp::List subboafit(
   Rcpp::NumericVector data
   ,int verb = 0
-  ,int method = 6
+  ,int method = 2
   ,int interv_step = 10
   ,Rcpp::Nullable<Rcpp::NumericVector> provided_m_ = R_NilValue
   ,Rcpp::NumericVector par = Rcpp::NumericVector::create(2., 2., 1., 1., 0.)
@@ -526,9 +527,8 @@ Rcpp::List subboafit(
   // Name of parameters
   Rcpp::CharacterVector param_names =
     Rcpp::CharacterVector::create("bl", "br", "al", "ar", "m");
-
-  /* store possibly provided values for parameters */
-  unsigned is_m_provided = 0;
+  Rcpp::CharacterVector param_names_m =
+    Rcpp::CharacterVector::create("bl", "br", "al", "ar");
 
   // define optimization parameters
   struct multimin_params global_oparams =
@@ -556,8 +556,6 @@ Rcpp::List subboafit(
   // initial value for m parameter
   if(provided_m_.isNotNull()){
 
-    is_m_provided = 1;
-
     // casting the null value
     // necessary according to
     // https://gallery.rcpp.org/articles/optional-null-function-arguments/
@@ -568,10 +566,11 @@ Rcpp::List subboafit(
   }
 
   /* store data */
-  unsigned int Size = data.size();/*the number of data*/
+  // number of data obs.
+  unsigned int Size = data.size();
 
   /* store guess */
-  double   fmin=0;
+  double fmin=0;
 
   /* customized admin. of errors */
   /* --------------------------- */
@@ -599,15 +598,15 @@ Rcpp::List subboafit(
   if(method == 0){
 
     // main dataframe with coefficients
-    Rcpp::DataFrame dt =
-      Rcpp::DataFrame::create( Rcpp::Named("param") = param_names
-                               ,Rcpp::Named("coef") = par
-                               );
+    Rcpp::DataFrame dt = Rcpp::DataFrame::create(
+        Rcpp::Named("param") = param_names
+        ,Rcpp::Named("coef") = par
+    );
 
     Rcpp::List ans = Rcpp::List::create(
-                                        Rcpp::Named("dt")              = dt
-                                        ,Rcpp::Named("log-likelihood") = fmin
-                                        );
+        Rcpp::Named("dt")              = dt
+        ,Rcpp::Named("log-likelihood") = fmin
+    );
     return ans;
 
   }
@@ -618,25 +617,24 @@ Rcpp::List subboafit(
   if(method >= 1){
 
     // notice: par is updated by reference
-    Rcpp::List g_opt_results =
-      global_optim(
-                   data
-                   ,fmin
-                   ,global_oparams
-                   ,par
-                   ,(unsigned) 5
-                   ,(unsigned) 4
-                   ,subboa_objf
-                   ,subboa_objdf
-                   ,subboa_objfdf
-                   ,provided_m_
-                   ,verb
-                   );
+    Rcpp::List g_opt_results = global_optim(
+      data
+      ,fmin
+      ,global_oparams
+      ,par
+      ,(unsigned) 5
+      ,(unsigned) 4
+      ,subboa_objf
+      ,subboa_objdf
+      ,subboa_objfdf
+      ,provided_m_
+      ,verb
+    );
 
     /* interval optimization  */
     /* ---------------------- */
 
-    if(method >= 2){
+    if(method == 2 && provided_m_.isNull()){
 
       g_opt_results = interval_optim(
         data
@@ -663,7 +661,8 @@ Rcpp::List subboafit(
   // generate outputs
 
   // variables
-  const size_t dim=(is_m_provided?4:5); /* set the size of the var-covar matrix */
+  // set the size of the var-covar matrix
+  int dim=(provided_m_.isNotNull()?4:5);
 
   /* allocate var-covar matrix */
   // The V matrix has on its main diagonal the variance of parameters
@@ -671,16 +670,13 @@ Rcpp::List subboafit(
   // on the upper diagonal the covariances
   RcppGSL::Matrix V =  subboa_varcovar(par, Size, dim);
   // this matrix in its upper diagonal presents the covariances
-  // and on its lower diagonal presents the correlation coefficients between the parameters
+  // and on its lower diagonal presents the correlation coefficients between the
+  // parameters
 
   // vector of standard errors
-  Rcpp::NumericVector std_error = Rcpp::NumericVector::create(
-     sqrt(V(0,0)) // bl
-    ,sqrt(V(1,1)) // br
-    ,sqrt(V(2,2)) // al
-    ,sqrt(V(3,3)) // ar
-    ,sqrt(V(4,4)) // m
-  );
+  Rcpp::NumericVector std_error = Rcpp::NumericVector::create(0., 0., 0., 0., 0.);
+  int i;
+  for(i=0; i<dim; i++) std_error[i] = sqrt(V(i,i));
 
   // main dataframe with coefficients
   Rcpp::List dt = Rcpp::DataFrame::create(
@@ -693,7 +689,7 @@ Rcpp::List subboafit(
   Rcpp::NumericMatrix matrix = Rcpp::as<Rcpp::NumericMatrix>(Rcpp::wrap(V));
 
   // add names for the matrices
-  colnames(matrix) = param_names;
+  colnames(matrix) = (provided_m_.isNotNull()?param_names_m:param_names);
 
   Rcpp::List ans = Rcpp::List::create(
       Rcpp::Named("dt")             = dt
