@@ -81,7 +81,6 @@ RcppGSL::Matrix subbo_varcovar(
   /* a - a */
   I(1,1) = b/(a*a);
 
-
   if(dim == 3){
 
     /* b - m */
@@ -556,7 +555,7 @@ Rcpp::List optim_method_moments(
 //'
 //' \code{subbofit} returns the parameters, standard errors. negative
 //' log-likelihood and covariance matrix of the Subbotin Distribution for a
-//' sample. The process can execute three steps, dependending on the level of
+//' sample. The process can execute three steps, depending on the level of
 //' accuracy required. See details below.
 //'
 //'
@@ -567,7 +566,7 @@ Rcpp::List optim_method_moments(
 //' \deqn{A = 2ab^{1/b}\Gamma(1+1/b)}
 //' where \eqn{a} is a scale parameter, \eqn{b} controls the tails (lower values
 //' represent fatter tails), and \eqn{m} is a location parameter. Due to its
-//' simmetry, the equations are simple enough to be estimated by the method of
+//' symmetry, the equations are simple enough to be estimated by the method of
 //' moments, which produce rough estimations that should be used only for first
 //' explorations. The maximum likelihood global estimation improves on this
 //' initial guess by using a optimization routine, defaulting to the
@@ -583,7 +582,7 @@ Rcpp::List optim_method_moments(
 //'
 //' @param data (NumericVector) - the sample used to fit the distribution.
 //' @param verb (int) - the level of verbosity. Select one of:
-//' * 0  just the final result
+//' * 0  just the final result (default)
 //' * 1  headings and summary table
 //' * 2  intermediate steps results
 //' * 3  intermediate steps internals
@@ -594,12 +593,13 @@ Rcpp::List optim_method_moments(
 //' * 1 initial estimation based on method of moments
 //' * 2 global optimization not considering lack of smoothness in m
 //' * 3 interval optimization taking non-smoothness in m into consideration
+//'   (default, only occurs if provided_m_ is null)
 //' @param interv_step  int - the number of intervals to be explored after
 //' the last minimum was found in the interval optimization. Default is 10.
-//' @param provided_m_ NumericVector - if NULL, the m parameter is estimated
-//' by the routine. If numeric, the estimation fixes m to the given value.
+//' @param provided_m_ NumericVector - if NULL (default), the m parameter is
+//' estimated by the routine. If numeric, the estimation fixes m to the given value.
 //' @param par NumericVector - vector containing the initial guess for
-//' parameters b, a and m, respectively. Default values of are c(2, 1, 0).
+//' parameters b, a and m, respectively. Default values are c(2, 1, 0).
 //' @param g_opt_par NumericVector - vector containing the global optimization
 //' parameters.
 //' The optimization parameters are:
@@ -652,8 +652,11 @@ Rcpp::List subbofit(
   /* initial values */
   /* -------------- */
 
-  /* store possibly provided values for parameters */
-  unsigned is_m_provided = 0;
+  // Name of parameters
+  Rcpp::CharacterVector param_names =
+    Rcpp::CharacterVector::create("b", "a", "m");
+  Rcpp::CharacterVector param_names_m =
+    Rcpp::CharacterVector::create("b", "a");
 
   // define optimization parameters
   struct multimin_params global_oparams =
@@ -678,15 +681,9 @@ Rcpp::List subbofit(
   // necessary according to
   // https://gallery.rcpp.org/articles/optional-null-function-arguments/
 
-  // initial value for m parameter
-  if(provided_m_.isNotNull()){
-
-    is_m_provided = 1;
-
-  }
-
   /* store data */
-  unsigned int Size = data.size();/*the number of data*/
+  //number of data obs.
+  unsigned int Size = data.size();
 
   // Fisher Matrix or negative log-likelihood?
   // log_likelihood
@@ -722,14 +719,10 @@ Rcpp::List subbofit(
   /* --------------- */
   if(method == 0){
 
-    // Name of parameters
-    Rcpp::CharacterVector param_names =
-      Rcpp::CharacterVector::create("b", "a", "m");
-
     // main dataframe with coefficients
       Rcpp::DataFrame dt = Rcpp::DataFrame::create(
-         Rcpp::Named("param") = param_names
-         ,Rcpp::Named("coef") = par
+        Rcpp::Named("param") = param_names
+        ,Rcpp::Named("coef") = par
       );
 
       Rcpp::List ans = Rcpp::List::create(
@@ -787,7 +780,7 @@ Rcpp::List subbofit(
     /* interval optimization  */
     /* ---------------------- */
 
-    if(method >= 3){
+    if(method == 3 && provided_m_.isNull()){
 
       g_opt_results = interval_optim(
         data
@@ -819,9 +812,10 @@ Rcpp::List subbofit(
 
   // generate outputs
   // variables
-  const size_t dim=(is_m_provided?2:3); /* set the size of the var-covar matrix */
 
   /* allocate var-covar matrix */
+  // if provided_m, std of m in the Cov matrix is null
+  int dim=(provided_m_.isNotNull()?2:3);
   // The V matrix has on its main diagonal the variance of parameters
   // on the lower diagonal the correlation coefficients
   // on the upper diagonal the covariances
@@ -830,14 +824,9 @@ Rcpp::List subbofit(
   // and on its lower diagonal presents the correlation coefficients between the parameters
 
   // vector of standard errors
-  Rcpp::NumericVector std_error = Rcpp::NumericVector::create(
-     sqrt(V(0,0)) // b
-    ,sqrt(V(1,1)) // a
-    ,sqrt(V(2,2)) // m
-  );
-
-   // Name of parameters
-   Rcpp::CharacterVector param_names = Rcpp::CharacterVector::create("b", "a", "m");
+  Rcpp::NumericVector std_error = Rcpp::NumericVector::create(0., 0., 0.);
+  int i;
+  for(i=0; i<dim; i++) std_error[i] = sqrt(V(i,i));
 
    // main dataframe with coefficients
    Rcpp::List dt = Rcpp::DataFrame::create(
@@ -850,7 +839,7 @@ Rcpp::List subbofit(
   Rcpp::NumericMatrix matrix = Rcpp::as<Rcpp::NumericMatrix>(Rcpp::wrap(V));
 
   // add names for the matrices
-  colnames(matrix) = param_names;
+  colnames(matrix) = (provided_m_.isNotNull()?param_names_m:param_names);
 
   Rcpp::List ans = Rcpp::List::create(
       Rcpp::Named("dt")             = dt
